@@ -197,16 +197,14 @@ namespace qdesigner_internal
         if (flagIds.isEmpty())
             return QString();
 
-        const QChar delimiter = QLatin1Char('|');
         QString rc;
-        const QStringList::const_iterator cend = flagIds.constEnd();
-        for (QStringList::const_iterator it = flagIds.constBegin(); it != cend; ++it) {
+        for (const auto &id : flagIds) {
             if (!rc.isEmpty())
-                rc += delimiter ;
+                rc += u'|';
             if (sm == FullyQualified)
-                appendQualifiedName(*it, rc);
+                appendQualifiedName(id, rc);
             else
-                rc += *it;
+                rc += id;
         }
         return rc;
     }
@@ -221,9 +219,9 @@ namespace qdesigner_internal
         }
         uint flags = 0;
         bool valueOk = true;
-        QStringList keys = s.split(QString(QLatin1Char('|')));
-        for (auto it = keys.constBegin(), cend = keys.constEnd(); it != cend; ++it) {
-            const uint flagValue = keyToValue(*it, &valueOk);
+        const QStringList keys = s.split(u'|');
+        for (const QString &key : keys) {
+            const uint flagValue = keyToValue(key, &valueOk);
             if (!valueOk) {
                 flags = 0;
                 break;
@@ -272,7 +270,7 @@ namespace qdesigner_internal
     {
         if (const QDesignerLanguageExtension *lang = qt_extension<QDesignerLanguageExtension *>(core->extensionManager(), core))
             return lang->isLanguageResource(path) ?  LanguageResourcePixmap : FilePixmap;
-        return path.startsWith(QLatin1Char(':')) ? ResourcePixmap : FilePixmap;
+        return path.startsWith(u':') ? ResourcePixmap : FilePixmap;
     }
 
     int PropertySheetPixmapValue::compare(const PropertySheetPixmapValue &other) const
@@ -388,7 +386,7 @@ namespace qdesigner_internal
 
     QPixmap DesignerPixmapCache::pixmap(const PropertySheetPixmapValue &value) const
     {
-        QMap<PropertySheetPixmapValue, QPixmap>::const_iterator it = m_cache.constFind(value);
+        const auto it = m_cache.constFind(value);
         if (it != m_cache.constEnd())
             return it.value();
 
@@ -697,8 +695,8 @@ namespace qdesigner_internal
             }
         }
         if (!action) {
-            if (const QDesignerTaskMenuExtension *taskMenu = qobject_cast<QDesignerTaskMenuExtension *>(
-                        core->extensionManager()->extension(managedWidget, QStringLiteral("QDesignerInternalTaskMenuExtension")))) {
+            if (const auto *taskMenu = qobject_cast<QDesignerTaskMenuExtension *>(
+                        core->extensionManager()->extension(managedWidget, u"QDesignerInternalTaskMenuExtension"_s))) {
                 action = taskMenu->preferredEditAction();
                 if (!action) {
                     const auto actions = taskMenu->taskActions();
@@ -715,12 +713,12 @@ namespace qdesigner_internal
     {
         QProcess uic;
         QStringList arguments;
-        QString binary = QLibraryInfo::path(QLibraryInfo::LibraryExecutablesPath) + QStringLiteral("/uic");
+        QString binary = QLibraryInfo::path(QLibraryInfo::LibraryExecutablesPath) + "/uic"_L1;
         switch (language) {
         case UicLanguage::Cpp:
             break;
         case UicLanguage::Python:
-            arguments << QLatin1String("-g") << QLatin1String("python");
+            arguments << u"-g"_s << u"python"_s;
             break;
         }
         arguments << fileName;
@@ -752,7 +750,7 @@ namespace qdesigner_internal
 
         if (qname.size() > 1 && qname.at(1).isUpper()) {
             const QChar first = qname.at(0);
-            if (first == QLatin1Char('Q') || first == QLatin1Char('K'))
+            if (first == u'Q' || first == u'K')
                 qname.remove(0, 1);
         }
 
@@ -782,7 +780,9 @@ namespace qdesigner_internal
 quint64 paletteResolveMask(QPalette::ColorGroup colorGroup,
                            QPalette::ColorRole colorRole)
 {
-    const auto offset = quint64(QPalette::NColorRoles) * quint64(colorGroup);
+    if (colorRole == QPalette::Accent)
+        colorRole = QPalette::NoRole; // See qtbase/17c589df94a2245ee92d45839c2cba73566d7310
+    const auto offset = quint64(QPalette::NColorRoles - 1) * quint64(colorGroup);
     const auto bitPos = quint64(colorRole) + offset;
     return 1ull << bitPos;
 }
